/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.picketbox.core.config;

import java.util.ArrayList;
import java.util.List;

import org.picketbox.core.identity.DefaultIdentityManager;
import org.picketbox.core.identity.IdentityManager;
import org.picketbox.core.identity.impl.LDAPBasedIdentityManager;

/**
 * @author <a href="mailto:psilva@redhat.com">Pedro Silva</a>
 *
 */
public class IdentityManagerConfigurationBuilder extends AbstractConfigurationBuilder<IdentityManagerConfiguration> {

    private List<IdentityManager> managers;
    private LDAPIdentityManagerConfigurationBuilder ldapIdentityManagerManager;

    public IdentityManagerConfigurationBuilder(ConfigurationBuilder builder) {
        super(builder);
        this.managers = new ArrayList<IdentityManager>();
    }

    @Override
    protected void setDefaults() {
        if (this.ldapIdentityManagerManager != null) {
            this.managers.add(new LDAPBasedIdentityManager(this.ldapIdentityManagerManager.build()));
        }

        if (this.managers.isEmpty()) {
            this.managers.add(new DefaultIdentityManager());
        }
    }

    public IdentityManagerConfigurationBuilder manager(IdentityManager identityManager) {
        if (identityManager != null) {
            this.managers.add(identityManager);
        }

        return this;
    }

    public LDAPIdentityManagerConfigurationBuilder ldap() {
        if (this.ldapIdentityManagerManager == null) {
            this.ldapIdentityManagerManager = new LDAPIdentityManagerConfigurationBuilder(this);
        }
        return this.ldapIdentityManagerManager;
    }

    @Override
    public IdentityManagerConfiguration doBuild() {
        return new IdentityManagerConfiguration(this.managers);
    }

}
